Module: HouseAccount
- Defined in:
- lib/houseaccount.rb,
lib/houseaccount/version.rb
Overview
The Ruby House Account shares between the apps it runs.
Constant Summary collapse
- VERSION =
The version of this gem, as RubyGems knows it.
'0.1.0'
The Ruby House Account shares between the apps it runs.
The version of this gem, as RubyGems knows it.
'0.1.0'